==> qt-embedded-free-3.0.7.tar.gz: qt-embedded-free-3.0.7/src/kernel/qt.h <==
/****************************************************************************
**
** Qt GUI Toolkit
**
** This header file efficiently includes all Qt GUI Toolkit functionality.
**
** Generated : Fri Oct  5 11:04:00 EST 2001

**
** Copyright (C) 1995-2000 Trolltech AS.  All rights reserved.
**
** This file is part of the Qt GUI Toolkit.
**
*****************************************************************************/

#ifndef QT_H
#define QT_H
#include "qglobal.h"
#include <qfeatures.h>
#include "qshared.h"
#include "qptrcollection.h"
#include "qglist.h"
#include "qobjectdefs.h"
#include "qnamespace.h"
#include "qgarray.h"
#include "qmemarray.h"
#include "qcstring.h"
#include "qstring.h"
#include "qwindowdefs.h"
#include "qplatformdefs.h"
#include "qkeysequence.h"
#include "qfont.h"
#include "qgdict.h"
#include "qcolor.h"
#include "qpair.h"
#include "qpoint.h"
#include "qptrlist.h"
#include "qsize.h"
#include "qpen.h"
#include "qfontinfo.h"
#include "qsizepolicy.h"
#include "qiodevice.h"
#include <qrect.h>
#include "qdatastream.h"
#include "qbitarray.h"
#include "qregion.h"
#include "qsql.h"
#include <stdio.h>
#include "qtextstream.h"
#include "qfontmetrics.h"
#include "qdatetime.h"
#include "qbrush.h"
#include "qasciidict.h"
#include "qpaintdevice.h"
#include "qpalette.h"
#include "qdict.h"
#include "qtl.h"
#include "qhostaddress.h"
#include "qvaluelist.h"
#include "qmap.h"
#include "qmime.h"
#include <qdom.h>
#include "qevent.h"
#include <qdrawutil.h>
#include "qobject.h"
#include "qwidget.h"
#include "qframe.h"
#include "qjpunicode.h"
#include "qtextcodec.h"
#include "qrangecontrol.h"
#include "qdialog.h"
#include "qfile.h"
#include "qstrlist.h"
#include "qurlinfo.h"
#include <qwidgetlist.h>
#include <qcombobox.h>
#include <qfontdialog.h>
#include <qdataview.h>
#include "qstyle.h"
#include "qgroupbox.h"
#include "qcommonstyle.h"
#include <qeuckrcodec.h>
#include <qgb18030codec.h>
#include "qgcache.h"
#include "qdockwindow.h"
#include <qgif.h>
#include <qglcolormap.h>
#include <qcache.h>
#include <qdropsite.h>
#include "qgplugin.h"
#include <qgrid.h>
#include "qscrollbar.h"
#include "qbuttongroup.h"
#include <qdatetimeedit.h>
#include "qgvector.h"
#include "qhbox.h"
#include <qhbuttongroup.h>
#include "qpixmap.h"
#include <qhgroupbox.h>
#include "qsocketnotifier.h"
#include "qnetworkprotocol.h"
#include "qiconset.h"
#include "qbuffer.h"
#include "qstringlist.h"
#include <qimageformatplugin.h>
#include <qlineedit.h>
#include <qintcache.h>
#include "qintdict.h"
#include "qmotifstyle.h"
#include <qpicture.h>
#include <qjiscodec.h>
#include <qeucjpcodec.h>
#include <qkeycode.h>
#include <qaccel.h>
#include "qlabel.h"
#include "qlayout.h"
#include <qlcdnumber.h>
#include <qlibrary.h>
#include <qinputdialog.h>
#include "qscrollview.h"
#include <qlistview.h>
#include "qfileinfo.h"
#include "qwindowsstyle.h"
#include "qconnection.h"
#include <qheader.h>
#include "qvariant.h"
#include "qsignal.h"
#include <qmessagebox.h>
#include "qmetaobject.h"
#include <qaction.h>
#include <qmotifplusstyle.h>
#include <qcdestyle.h>
#include <qmovie.h>
#include "qptrvector.h"
#include "qmutex.h"
#include "qbutton.h"
#include <qnetwork.h>
#include <qftp.h>
#include "qguardedptr.h"
#include <qobjectcleanuphandler.h>
#include "qtimer.h"
#include <qobjectdict.h>
#include <qobjectlist.h>
#include <qbitmap.h>
#include <qpaintdevicemetrics.h>
#include "qpointarray.h"
#include "qdir.h"
#include <qerrormessage.h>
#include "qptrdict.h"
#include "qimage.h"
#include "qsqlfield.h"
#include <qpixmapcache.h>
#include "qmenudata.h"
#include <qplatinumstyle.h>
#include <qpngio.h>
#include <qcursor.h>
#include <qcolordialog.h>
#include <qpolygonscanner.h>
#include "qpopupmenu.h"
#include <qprintdialog.h>
#include <qprinter.h>
#include <qprocess.h>
#include "qprogressbar.h"
#include "qsemimodal.h"
#include <qasciicache.h>
#include <qcanvas.h>
#include <qcleanuphandler.h>
#include <qptrqueue.h>
#include <qptrstack.h>
#include "qstylesheet.h"
#include <qpushbutton.h>
#include <qradiobutton.h>
#include <qdial.h>
#include <qdockarea.h>
#include "qregexp.h"
#include <qclipboard.h>
#include <qrtlcodec.h>
#include <qlistbox.h>
#include <qgridview.h>
#include "qsemaphore.h"
#include <qprogressdialog.h>
#include "qsocketdevice.h"
#include <qsessionmanager.h>
#include <qsettings.h>
#include <qsgistyle.h>
#include "qtranslator.h"
#include <qmenubar.h>
#include <qsignalmapper.h>
#include <qsignalslotimp.h>
#include <qsimplerichtext.h>
#include "qwmatrix.h"
#include <qsizegrip.h>
#include <qabstractlayout.h>
#include <qsjiscodec.h>
#include <qslider.h>
#include <qsocket.h>
#include <qserversocket.h>
#include <qdns.h>
#include <qsortedlist.h>
#include <qsound.h>
#include <qspinbox.h>
#include <qsplitter.h>
#include "qsqlerror.h"
#include "qeditorfactory.h"
#include "qsqlquery.h"
#include "qsqlrecord.h"
#include <qsqldriverplugin.h>
#include "qsqlindex.h"
#include "qsqlcursor.h"
#include <qsqldriver.h>
#include <qhttp.h>
#include "qtable.h"
#include <qsqlpropertymap.h>
#include <qsqldatabase.h>
#include <qdatabrowser.h>
#include <qsqlresult.h>
#include <qstatusbar.h>
#include <qdragobject.h>
#include <qasyncimageio.h>
#include <qfontdatabase.h>
#include <qstrvec.h>
#include <qinterlacestyle.h>
#include <qstylefactory.h>
#include <qstyleplugin.h>
#include "qtextedit.h"
#include <qtabbar.h>
#include <qtabdialog.h>
#include "qsqleditorfactory.h"
#include <qtabwidget.h>
#include <qtextbrowser.h>
#include <qbig5codec.h>
#include <qtextcodecfactory.h>
#include <qtextcodecplugin.h>
#include <qmultilineedit.h>
#include "qtoolbar.h"
#include <qtextview.h>
#include "qwaitcondition.h"
#include <qasyncio.h>
#include <qsqlform.h>
#include <qmainwindow.h>
#include <qtoolbutton.h>
#include <qtooltip.h>
#include "qdesktopwidget.h"
#include <qtsciicodec.h>
#include "qurl.h"
#include "qurloperator.h"
#include <qfiledialog.h>
#include <qutfcodec.h>
#include <quuid.h>
#include <qvalidator.h>
#include <qiconview.h>
#include <qvaluestack.h>
#include <qvaluevector.h>
#include <qdatatable.h>
#include <qvbox.h>
#include <qvbuttongroup.h>
#include <qvfbhdr.h>
#include <qvgroupbox.h>
#include <qthread.h>
#include <qwhatsthis.h>
#include <qapplication.h>
#include <qwidgetintdict.h>
#include <qfocusdata.h>
#include <qwidgetplugin.h>
#include <qwidgetstack.h>
#include <qcheckbox.h>
#include <qcompactstyle.h>
#include <qwizard.h>
#include <qpainter.h>
#include <qworkspace.h>
#include <qlocalfs.h>
#include <qxml.h>

#if defined( QT_MOC_CPP ) || defined( QT_H_CPP )
#include <limits.h>
#include <private/qcom_p.h>
#include "private/qcomplextext_p.h"
#include <private/qucom_p.h>
#include <private/qgpluginmanager_p.h>
#include <private/qimageformatinterface_p.h>
#include <private/qlayoutengine_p.h>
#include <private/qcom_p.h>
#include <private/qeffects_p.h>
#include <private/qcomlibrary_p.h>
#include <private/qinternal_p.h>
#include <private/qsqldriverinterface_p.h>
#include <private/qsqlmanager_p.h>
#include <private/qcomplextext_p.h>
#include <private/qcomponentfactory_p.h>
#include <private/qstyleinterface_p.h>
#include <private/qsvgdevice_p.h>
#include <private/qfontcodecs_p.h>
#include <private/qtextcodecinterface_p.h>
#include <private/qpsprinter_p.h>
#include <private/qtitlebar_p.h>
#include <private/qucom_p.h>
#include <private/qucomextra_p.h>
#include <private/qpluginmanager_p.h>
#include <private/qrichtext_p.h>
#include <private/qwidgetinterface_p.h>
#include <private/qwidgetresizehandler_p.h>
#include <private/qlibrary_p.h>
#endif // Private headers


#ifdef Q_WS_MAC
#include <qaquastyle.h>
#include <private/qaquastyle_p.h>
#endif // Q_WS_MAC


#ifdef Q_WS_QWS
#include "qfontmanager_qws.h"
#include <qfontfactorybdf_qws.h>
#include <qgfxvoodoodefs_qws.h>
#include <qgfxmatroxdefs_qws.h>
#include "qkeyboard_qws.h"
#include <qlock_qws.h>
#include <qcopchannel_qws.h>
#include <qdirectpainter_qws.h>
#include "qmemorymanager_qws.h"
#include <qfontfactoryttf_qws.h>
#include <qgfx_qws.h>
#include <qgfxvnc_qws.h>
#include <qsoundqss_qws.h>
#include "qwsdisplay_qws.h"
#include <qgfxraster_qws.h>
#include <qwssocket_qws.h>
#include "qwsdecoration_qws.h"
#include "qwsutils_qws.h"
#include <qwscursor_qws.h>
#include "qwsmanager_qws.h"
#include "qwsdefaultdecoration_qws.h"
#include "qwscommand_qws.h"
#include <qwshydrodecoration_qws.h>
#include <qwskde2decoration_qws.h>
#include <qwskdedecoration_qws.h>
#include <qwsbeosdecoration_qws.h>
#include <qwsmouse_qws.h>
#include "qwsproperty_qws.h"
#include <qwsregionmanager_qws.h>
#include "qwsevent_qws.h"
#include <qwindowsystem_qws.h>
#include <qwswindowsdecoration_qws.h>
#endif // Q_WS_QWS


#ifdef Q_WS_WCE
#include <qpocketpcstyle_wce.h>
#endif // Q_WS_WCE

#ifdef Q_OS_QNX6
#include <qwsmouse_qnx6.h>
#include <qwskeyboard_qnx6.h>
#endif

#ifdef Q_OS_QNX4
#include <qwsmouse_qnx4.h>
#include <qwskeyboard_qnx4.h>
#endif

#endif // QT_H

==> qt-embedded-free-3.3.0.tar.gz: qt-embedded-free-3.3.0/src/kernel/qt.h <==
/****************************************************************************
**
** Qt GUI Toolkit
**
** This header file efficiently includes all Qt GUI Toolkit functionality.
**
** Generated : Mon Oct 13 13:07:29 CEST 2003

**
** Copyright (C) 1995-2000 Trolltech AS.  All rights reserved.
**
** This file is part of the Qt GUI Toolkit.
**
*****************************************************************************/

#ifndef QT_H
#define QT_H
#include "qglobal.h"
#include "qfeatures.h"
#include "qshared.h"
#include "qptrcollection.h"
#include "qglist.h"
#include "qobjectdefs.h"
#include "qnamespace.h"
#include "qgarray.h"
#include "qmemarray.h"
#include "qcstring.h"
#include "qstring.h"
#include "qptrlist.h"
#include "qiodevice.h"
#include "qkeysequence.h"
#include "qwindowdefs.h"
#include "qgdict.h"
#include "qfont.h"
#include "qdatastream.h"
#include "qpair.h"
#include "qpoint.h"
#include <stdio.h>
#include "qtextstream.h"
#include "qfontinfo.h"
#include "qsizepolicy.h"
#include "qtl.h"
#include "qsize.h"
#include "qrect.h"
#include "qbitarray.h"
#include "qregion.h"
#include "qsql.h"
#include "qstrlist.h"
#include "qvaluelist.h"
#include "qmap.h"
#include "qdatetime.h"
#include "qmime.h"
#include "qasciidict.h"
#include "qpaintdevice.h"
#include "qfontmetrics.h"
#include "qdict.h"
#include "qevent.h"
#include "qhostaddress.h"
#include "qstringlist.h"
#include "qcolor.h"
#include <qdom.h>
#include "qobject.h"
#include <qdrawutil.h>
#include "qbrush.h"
#include "qpalette.h"
#include "qwidget.h"
#include "qjpunicode.h"
#include "qtextcodec.h"
#include "qstyle.h"
#include "qframe.h"
#include "qfile.h"
#include "qfileinfo.h"
#include "qurlinfo.h"
#include "qwidgetlist.h"
#include <qcombobox.h>
#include "qgroupbox.h"
#include "qdialog.h"
#include <qdataview.h>
#include "qdockwindow.h"
#include "qcommonstyle.h"
#include "qnetworkprotocol.h"
#include <qeuckrcodec.h>
#include <qgb18030codec.h>
#include "qgcache.h"
#include "qpixmap.h"
#include <qgif.h>
#include <qglcolormap.h>
#include <qcache.h>
#include <qdropsite.h>
#include "qgplugin.h"
#include <qgrid.h>
#include "qrangecontrol.h"
#include "qbuttongroup.h"
#include <qdatetimeedit.h>
#include "qgvector.h"
#include "qhbox.h"
#include <qhbuttongroup.h>
#include "qiconset.h"
#include <qhgroupbox.h>
#include "qsocketnotifier.h"
#include <qeventloop.h>
#include <qhttp.h>
#include <qaction.h>
#include "qbuffer.h"
#include "qimage.h"
#include <qimageformatplugin.h>
#include "qlineedit.h"
#include <qintcache.h>
#include "qintdict.h"
#include "qmotifstyle.h"
#include "qpicture.h"
#include <qjiscodec.h>
#include <qeucjpcodec.h>
#include <qkeycode.h>
#include <qaccel.h>
#include "qlabel.h"
#include "qlayout.h"
#include <qlcdnumber.h>
#include <qlibrary.h>
#include <qinputdialog.h>
#include "qscrollbar.h"
#include "qscrollview.h"
#include "qdir.h"
#include "qwindowsstyle.h"
#include "qconnection.h"
#include "qbitmap.h"
#include "qvariant.h"
#include "qsignal.h"
#include <qmessagebox.h>
#include "qmetaobject.h"
#include "qheader.h"
#include <qmotifplusstyle.h>
#include <qcdestyle.h>
#include <qmovie.h>
#include "qptrvector.h"
#include "qmutex.h"
#include "qbutton.h"
#include <qnetwork.h>
#include <qftp.h>
#include "qguardedptr.h"
#include <qobjectcleanuphandler.h>
#include "qsqlfield.h"
#include <qobjectdict.h>
#include <qobjectlist.h>
#include <qcolordialog.h>
#include <qpaintdevicemetrics.h>
#include "qpointarray.h"
#include "qmenudata.h"
#include <qlistview.h>
#include "qpen.h"
#include "qdragobject.h"
#include <qiconview.h>
#include <qpixmapcache.h>
#include <qplatinumstyle.h>
#include <qpngio.h>
#include <qcursor.h>
#include <qerrormessage.h>
#include <qpolygonscanner.h>
#include "qpopupmenu.h"
#include <qprintdialog.h>
#include <qprinter.h>
#include <qprocess.h>
#include "qprogressbar.h"
#include "qsemimodal.h"
#include <qasciicache.h>
#include "qptrdict.h"
#include <qcleanuphandler.h>
#include <qptrqueue.h>
#include <qptrstack.h>
#include "qstylesheet.h"
#include <qpushbutton.h>
#include <qradiobutton.h>
#include <qdial.h>
#include <qdockarea.h>
#include "qregexp.h"
#include <qclipboard.h>
#include <qrtlcodec.h>
#include <qlistbox.h>
#include <qgridview.h>
#include "qsemaphore.h"
#include <qprogressdialog.h>
#include "qsocketdevice.h"
#include <qsessionmanager.h>
#include <qsettings.h>
#include <qsgistyle.h>
#include <qfontdialog.h>
#include "qtimer.h"
#include <qsignalmapper.h>
#include <qsignalslotimp.h>
#include <qsimplerichtext.h>
#include "qwmatrix.h"
#include <qsizegrip.h>
#include <qabstractlayout.h>
#include <qsjiscodec.h>
#include <qslider.h>
#include <qsocket.h>
#include <qserversocket.h>
#include <qdns.h>
#include <qsortedlist.h>
#include <qsound.h>
#include <qspinbox.h>
#include <qsplashscreen.h>
#include <qsplitter.h>
#include "qsqlerror.h"
#include "qeditorfactory.h"
#include "qsqlquery.h"
#include "qsqlrecord.h"
#include <qsqldriverplugin.h>
#include "qsqlindex.h"
#include "qsqlcursor.h"
#include <qsqldriver.h>
#include <qsqlform.h>
#include "qtable.h"
#include <qsqlpropertymap.h>
#include <qsqldatabase.h>
#include <qdatabrowser.h>
#include <qsqlresult.h>
#include <qsqlselectcursor.h>
#include <qstatusbar.h>
#include <qmenubar.h>
#include <qcanvas.h>
#include "qtranslator.h"
#include <qstrvec.h>
#include <qinterlacestyle.h>
#include <qstylefactory.h>
#include <qstyleplugin.h>
#include "qtextedit.h"
#include <qsyntaxhighlighter.h>
#include <qtabbar.h>
#include <qtabdialog.h>
#include "qsqleditorfactory.h"
#include <qtabwidget.h>
#include <qtextbrowser.h>
#include <qbig5codec.h>
#include <qtextcodecfactory.h>
#include <qtextcodecplugin.h>
#include <qmultilineedit.h>
#include "qtoolbar.h"
#include <qtextview.h>
#include "qwaitcondition.h"
#include <qasyncio.h>
#include <qfontdatabase.h>
#include <qmainwindow.h>
#include <qtoolbox.h>
#include <qtoolbutton.h>
#include <qtooltip.h>
#include "qdesktopwidget.h"
#include <qtsciicodec.h>
#include "qurl.h"
#include "qurloperator.h"
#include <qfiledialog.h>
#include <qutfcodec.h>
#include <quuid.h>
#include <qvalidator.h>
#include <qasyncimageio.h>
#include <qvaluestack.h>
#include <qvaluevector.h>
#include <qdatatable.h>
#include <qvbox.h>
#include <qvbuttongroup.h>
#include <qvfbhdr.h>
#include <qvgroupbox.h>
#include <qthread.h>
#include <qwhatsthis.h>
#include <qapplication.h>
#include <qwidgetintdict.h>
#include <qfocusdata.h>
#include <qwidgetplugin.h>
#include <qwidgetstack.h>
#include <qcheckbox.h>
#include <qcompactstyle.h>
#include <qwizard.h>
#include <qpainter.h>
#include <qworkspace.h>
#include <qlocalfs.h>
#include <qxml.h>

#if defined( QT_MOC_CPP ) || defined( QT_H_CPP ) || defined( Q_OS_MACX )
#include <private/qcom_p.h>
#include <private/qucom_p.h>
#include "private/qgfxdriverinterface_p.h"
#include "private/qcom_p.h"
#include "private/qimageformatinterface_p.h"
#include "private/qisciicodec_p.h"
#include "private/qkbddriverinterface_p.h"
#include "private/qlayoutengine_p.h"
#include "private/qcomlibrary_p.h"
#include "private/qmousedriverinterface_p.h"
#include "private/qeffects_p.h"
#include "private/qgpluginmanager_p.h"
#include "private/qinternal_p.h"
#include "private/qsqldriverinterface_p.h"
#include "private/qsqlmanager_p.h"
#include "private/qlock_p.h"
#include "private/qcomponentfactory_p.h"
#include "private/qstyleinterface_p.h"
#include "private/qrichtext_p.h"
#include "private/qsvgdevice_p.h"
#include "private/qfontcodecs_p.h"
#include "private/qtextcodecinterface_p.h"
#include "private/qpsprinter_p.h"
#include "private/qtitlebar_p.h"
#include "private/qucom_p.h"
#include "private/qucomextra_p.h"
#include "private/qpluginmanager_p.h"
#include "private/qdir_p.h"
#include "private/qsettings_p.h"
#include "private/qsqlextension_p.h"
#include "private/qdialogbuttons_p.h"
#include "private/qwidgetinterface_p.h"
#include "private/qwidgetresizehandler_p.h"
#include "private/qlibrary_p.h"
#endif // Private headers


#ifdef Q_WS_MAC
#include <qaquastyle.h>
#include <qmacstyle_mac.h>
#endif // Q_WS_MAC

#ifdef Q_WS_WIN
#include <qwindowsxpstyle.h>
#endif

#ifdef Q_WS_QWS
#include <private/qtextengine_p.h>
#include "qfontmanager_qws.h"
#include <qfontfactorybdf_qws.h>
#include <qgfxvoodoodefs_qws.h>
#include <qgfxmatroxdefs_qws.h>
#include <qgfxdriverplugin_qws.h>
#include <qkbddriverfactory_qws.h>
#include <qkbddriverplugin_qws.h>
#include <qmousedriverfactory_qws.h>
#include <qmousedriverplugin_qws.h>
#include <qcopchannel_qws.h>
#include <qdirectpainter_qws.h>
#include "qmemorymanager_qws.h"
#include <qmouse_qws.h>
#include <qfontfactoryttf_qws.h>
#ifndef Q_OS_MAC
# include <qsoundqss_qws.h>
#endif
#include "qgfx_qws.h"
#include <qgfxdriverfactory_qws.h>
#include "qwsdisplay_qws.h"
#include "qwssocket_qws.h"
#include "qwsdecoration_qws.h"
#include "qwsutils_qws.h"
#include <qwscursor_qws.h>
#include "qwsmanager_qws.h"
#include "qwsdefaultdecoration_qws.h"
#include <qgfxraster_qws.h>
#include "qwscommand_qws.h"
#include <qwshydrodecoration_qws.h>
#include <qwskde2decoration_qws.h>
#include <qwskdedecoration_qws.h>
#include <qwsbeosdecoration_qws.h>
#include "qwsproperty_qws.h"
#include <qwsregionmanager_qws.h>
#include "qwsevent_qws.h"
#include <qwindowsystem_qws.h>
#include <qwswindowsdecoration_qws.h>
#endif // Q_WS_QWS


#ifdef Q_WS_WCE
#include <qpocketpcstyle_wce.h>
#endif // Q_WS_WCE

#endif // QT_H
